Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(769)

Unified Diff: chrome/app/breakpad_win.cc

Issue 10422019: Rename some chrome.exe exports: SetCommandLine --> SetCommandLine2, SetExperimentList --> SetExperi… (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Add comments on why the new name Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/app/breakpad_field_trial_win.cc ('k') | chrome/common/child_process_logging_win.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/app/breakpad_win.cc
diff --git a/chrome/app/breakpad_win.cc b/chrome/app/breakpad_win.cc
index 90a98e93c1f76968f69e323ad88b57b5bc830b63..0588c88c96e790d1f79cc5ac96fce47f92f98081 100644
--- a/chrome/app/breakpad_win.cc
+++ b/chrome/app/breakpad_win.cc
@@ -151,7 +151,10 @@ bool IsBoringCommandLineSwitch(const std::wstring& flag) {
flag == L"--flag-switches-end";
}
-extern "C" void __declspec(dllexport) __cdecl SetCommandLine(
+// Note that this is suffixed with "2" due to a parameter change that was made
+// to the predecessor "SetCommandLine()". If the signature changes again, use
+// a new name.
+extern "C" void __declspec(dllexport) __cdecl SetCommandLine2(
const wchar_t** argv, size_t argc) {
if (!g_custom_entries)
return;
@@ -302,7 +305,7 @@ google_breakpad::CustomClientInfo* GetCustomInfo(const std::wstring& exe_path,
google_breakpad::CustomInfoEntry(L"guid", guid.c_str()));
// Add empty values for the command line switches. We will fill them with
// actual values as part of SetCommandLine().
g_num_switches_offset = g_custom_entries->size();
g_custom_entries->push_back(
google_breakpad::CustomInfoEntry(L"num-switches", L""));
@@ -315,12 +318,12 @@ google_breakpad::CustomClientInfo* GetCustomInfo(const std::wstring& exe_path,
}
// Fill in the command line arguments using CommandLine::ForCurrentProcess().
// The browser process may call SetCommandLine() again later on with a command
// line that has been augmented with the about:flags experiments.
std::vector<const wchar_t*> switches;
StringVectorToCStringVector(
CommandLine::ForCurrentProcess()->argv(), &switches);
- SetCommandLine(&switches[0], switches.size());
+ SetCommandLine2(&switches[0], switches.size());
if (type == L"renderer" || type == L"plugin" || type == L"gpu-process") {
g_num_of_views_offset = g_custom_entries->size();
@@ -831,4 +834,4 @@ void StringVectorToCStringVector(const std::vector<std::wstring>& wstrings,
cstrings->reserve(wstrings.size());
for (size_t i = 0; i < wstrings.size(); ++i)
cstrings->push_back(wstrings[i].c_str());
-}
+}
« no previous file with comments | « chrome/app/breakpad_field_trial_win.cc ('k') | chrome/common/child_process_logging_win.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -302,7 +305,7 @@ google_breakpad::CustomClientInfo* GetCustomInfo(const std::wstring& exe_path,
google_breakpad::CustomInfoEntry(L"guid", guid.c_str()));
// Add empty values for the command line switches. We will fill them with
- // actual values as part of SetCommandLine().
+ // actual values as part of SetCommandLine2().
g_num_switches_offset = g_custom_entries->size();
g_custom_entries->push_back(
@@ -315,12 +318,12 @@ google_breakpad::CustomClientInfo* GetCustomInfo(const std::wstring& exe_path,
}
// Fill in the command line arguments using CommandLine::ForCurrentProcess().
- // The browser process may call SetCommandLine() again later on with a command
- // line that has been augmented with the about:flags experiments.
+ // The browser process may call SetCommandLine2() again later on with a
+ // command line that has been augmented with the about:flags experiments.
std::vector<const wchar_t*> switches;
StringVectorToCStringVector(
This is Rietveld 408576698